@@ -49,6 +49,12 @@
 
 using namespace std;
 
+XAPIAN_NORETURN(static void no_subdatabases());
+static void no_subdatabases()
+{
+    throw Xapian::DocNotFoundError("No subdatabases");
+}
+
 namespace Xapian {
 
 Database::Database()
@@ -124,6 +130,9 @@ Database::postlist_begin(const string &tname) const
     if (internal.size() == 1)
 	RETURN(PostingIterator(internal[0]->open_post_list(tname)));
 
+    if (rare(internal.size() == 0))
+	RETURN(PostingIterator(NULL));
+
     vector<LeafPostList *> pls;
     try {
 	vector<Xapian::Internal::RefCntPtr<Database::Internal> >::const_iterator i;
@@ -151,6 +160,8 @@ Database::termlist_begin(Xapian::docid did) const
     if (did == 0) throw InvalidArgumentError("Document ID 0 is invalid");
 
     unsigned int multiplier = internal.size();
+    if (rare(multiplier == 0))
+	no_subdatabases();
     TermList *tl;
     if (multiplier == 1) {
 	// There's no need for the MultiTermList wrapper in the common case
@@ -176,12 +187,15 @@ TermIterator
 Database::allterms_begin(const std::string & prefix) const
 {
     DEBUGAPICALL(TermIterator, "Database::allterms_begin", "");
-    if (internal.empty()) RETURN(TermIterator(NULL));
-
-    if (internal.size() == 1)
-	RETURN(TermIterator(internal[0]->open_allterms(prefix)));
-
-    RETURN(TermIterator(new MultiAllTermsList(internal, prefix)));
+    TermList * tl;
+    if (rare(internal.size() == 0)) {
+	tl = NULL;
+    } else if (internal.size() == 1) {
+	tl = internal[0]->open_allterms(prefix);
+    } else {
+	tl = new MultiAllTermsList(internal, prefix);
+    }
+    RETURN(TermIterator(tl));
 }
 
 bool
@@ -206,10 +220,10 @@ Database::positionlist_begin(Xapian::docid did, const string &tname) const
     if (did == 0) throw InvalidArgumentError("Document ID 0 is invalid");
 
     unsigned int multiplier = internal.size();
-    Assert(multiplier != 0);
+    if (rare(multiplier == 0))
+	no_subdatabases();
     Xapian::doccount n = (did - 1) % multiplier; // which actual database
     Xapian::docid m = (did - 1) / multiplier + 1; // real docid in that database
-
     RETURN(PositionIterator(internal[n]->open_position_list(m, tname)));
 }
 
@@ -232,7 +246,6 @@ Database::get_lastdocid() const
     Xapian::docid did = 0;
 
     unsigned int multiplier = internal.size();
-    Assert(multiplier != 0);
     for (Xapian::doccount i = 0; i < multiplier; ++i) {
 	Xapian::docid did_i = internal[i]->get_lastdocid();
 	if (did_i) did = std::max(did, (did_i - 1) * multiplier + i + 1);
@@ -295,7 +308,8 @@ Database::get_doclength(Xapian::docid did) const
     if (did == 0) throw InvalidArgumentError("Document ID 0 is invalid");
 
     unsigned int multiplier = internal.size();
-    Assert(multiplier != 0);
+    if (rare(multiplier == 0))
+	no_subdatabases();
     Xapian::doccount n = (did - 1) % multiplier; // which actual database
     Xapian::docid m = (did - 1) / multiplier + 1; // real docid in that database
     RETURN(internal[n]->get_doclength(m));
@@ -308,7 +322,8 @@ Database::get_document(Xapian::docid did) const
     if (did == 0) throw InvalidArgumentError("Document ID 0 is invalid");
 
     unsigned int multiplier = internal.size();
-    Assert(multiplier != 0);
+    if (rare(multiplier == 0))
+	no_subdatabases();
     Xapian::doccount n = (did - 1) % multiplier; // which actual database
     Xapian::docid m = (did - 1) / multiplier + 1; // real docid in that database
 
