@@ -3,6 +3,7 @@
  * Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2002 Ananova Ltd
  * Copyright 2002,2003,2004,2005,2006,2007 Olly Betts
+ * Copyright 2008 Lemur Consulting Ltd
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -441,6 +442,14 @@ Database::Internal::get_metadata(const string &) const
     return string();
 }
 
+TermList *
+Database::Internal::open_metadata_keylist(const std::string &) const
+{
+    // Only implemented for some database backends - others will simply report
+    // there being no metadata keys.
+    return NULL;
+}
+
 void
 Database::Internal::set_metadata(const string &, const string &)
 {
@@ -462,7 +471,16 @@ Database::Internal::request_document(Xapian::docid /*did*/) const
 Xapian::Document::Internal *
 Database::Internal::collect_document(Xapian::docid did) const
 {
-    return open_document(did);
+    // Open the document lazily - collect document is only called by
+    // Enquire::Internal::read_doc() for a given MSetItem, so we know that the
+    // document already exists.
+    return open_document(did, true);
+}
+
+void
+Database::Internal::invalidate_doc_object(Xapian::Document::Internal *) const
+{
+    // Do nothing, by default
 }
 
 RemoteDatabase *
