@@ -358,7 +358,7 @@ PostlistChunkWriter::append(FlintTable * table, Xapian::docid did,
 /** Make the data to go at the start of the very first chunk.
  */
 static inline string
-make_start_of_first_chunk(Xapian::termcount entries,
+make_start_of_first_chunk(Xapian::doccount entries,
 			  Xapian::termcount collectionfreq,
 			  Xapian::docid new_did)
 {
@@ -424,7 +424,8 @@ PostlistChunkWriter::flush(FlintTable *table)
 
 	    // Extract existing counts from the first chunk so we can reinsert
 	    // them into the block we're renaming.
-	    Xapian::termcount num_ent, coll_freq;
+	    Xapian::doccount num_ent;
+	    Xapian::termcount coll_freq;
 	    {
 		cursor->read_tag();
 		const char *tagpos = cursor->current_tag.data();
@@ -562,7 +563,8 @@ PostlistChunkWriter::flush(FlintTable *table)
 	    Assert(ok);
 	    Assert(!tag.empty());
 
-	    Xapian::termcount num_ent, coll_freq;
+	    Xapian::doccount num_ent;
+	    Xapian::termcount coll_freq;
 	    {
 		const char * tagpos = tag.data();
 		const char * tagend = tagpos + tag.size();
@@ -637,7 +639,7 @@ void FlintPostList::read_number_of_entries(const char ** posptr,
 /** The format of a postlist is:
  *
  *  Split into chunks.  Key for first chunk is the termname (encoded as
- *  length - name).  Key for subsequent chunks is the same, followed by the
+ *  length : name).  Key for subsequent chunks is the same, followed by the
  *  document ID of the first document in the chunk (encoded as length of
  *  representation in first byte, and then docid).
  *
@@ -649,20 +651,21 @@ void FlintPostList::read_number_of_entries(const char ** posptr,
  *  4)  increment in docid to next item, followed by wdf and doclength of item
  *  5)  (4) repeatedly.
  *
- *  The first chunk begins with the number of entries, then the docid of the
- *  first document, then has the header of a standard chunk.
+ *  The first chunk begins with the number of entries, the collection
+ *  frequency, then the docid of the first document, then has the header of a
+ *  standard chunk.
  */
 FlintPostList::FlintPostList(Xapian::Internal::RefCntPtr<const FlintDatabase> this_db_,
-			     const string & tname_)
+			     const string & term_)
 	: this_db(this_db_),
-	  tname(tname_),
+	  term(term_),
 	  have_started(false),
 	  cursor(this_db->postlist_table.cursor_get()),
 	  is_at_end(false)
 {
-    DEBUGCALL(DB, void, "FlintPostList::ostList",
-	      this_db_.get() << ", " << tname_);
-    string key = FlintPostListTable::make_key(tname);
+    DEBUGCALL(DB, void, "FlintPostList::FlintPostList",
+	      this_db_.get() << ", " << term_);
+    string key = FlintPostListTable::make_key(term);
     int found = cursor->find_entry(key);
     if (!found) {
 	number_of_entries = 0;
@@ -719,15 +722,15 @@ FlintPostList::next_chunk()
     if (cursor->after_end()) {
 	is_at_end = true;
 	throw Xapian::DatabaseCorruptError("Unexpected end of posting list for `" +
-				     tname + "'");
+				     term + "'");
     }
     const char * keypos = cursor->current_key.data();
     const char * keyend = keypos + cursor->current_key.size();
     // Check we're still in same postlist
-    if (!check_tname_in_key_lite(&keypos, keyend, tname)) {
+    if (!check_tname_in_key_lite(&keypos, keyend, term)) {
 	is_at_end = true;
 	throw Xapian::DatabaseCorruptError("Unexpected end of posting list for `" +
-				     tname + "'");
+				     term + "'");
     }
 
     Xapian::docid newdid;
@@ -756,7 +759,7 @@ PositionList *
 FlintPostList::read_position_list()
 {
     DEBUGCALL(DB, PositionList *, "FlintPostList::read_position_list", "");
-    positionlist.read_data(&this_db->position_table, did, tname);
+    positionlist.read_data(&this_db->position_table, did, term);
     RETURN(&positionlist);
 }
 
@@ -764,7 +767,7 @@ PositionList *
 FlintPostList::open_position_list() const
 {
     DEBUGCALL(DB, PositionList *, "FlintPostList::open_position_list", "");
-    RETURN(new FlintPositionList(&this_db->position_table, did, tname));
+    RETURN(new FlintPositionList(&this_db->position_table, did, term));
 }
 
 PostList *
@@ -803,13 +806,13 @@ FlintPostList::move_to_chunk_containing(Xapian::docid desired_did)
 {
     DEBUGCALL(DB, void,
 	      "FlintPostList::move_to_chunk_containing", desired_did);
-    (void)cursor->find_entry(FlintPostListTable::make_key(tname, desired_did));
+    (void)cursor->find_entry(FlintPostListTable::make_key(term, desired_did));
     Assert(!cursor->after_end());
 
     const char * keypos = cursor->current_key.data();
     const char * keyend = keypos + cursor->current_key.size();
     // Check we're still in same postlist
-    if (!check_tname_in_key_lite(&keypos, keyend, tname)) {
+    if (!check_tname_in_key_lite(&keypos, keyend, term)) {
 	// This should only happen if the postlist doesn't exist at all.
 	is_at_end = true;
 	is_last_chunk = true;
@@ -905,7 +908,7 @@ FlintPostList::skip_to(Xapian::docid desired_did, Xapian::weight w_min)
 string
 FlintPostList::get_description() const
 {
-    return tname + ":" + om_tostring(number_of_entries);
+    return term + ":" + om_tostring(number_of_entries);
 }
 
 // Returns the last did to allow in this chunk.
@@ -1013,7 +1016,8 @@ FlintPostListTable::merge_changes(
 	    // Read start of first chunk to get termfreq and collfreq.
 	    const char *pos = tag.data();
 	    const char *end = pos + tag.size();
-	    Xapian::termcount termfreq, collfreq;
+	    Xapian::doccount termfreq;
+	    Xapian::termcount collfreq;
 	    Xapian::docid firstdid, lastdid;
 	    bool islast;
 	    if (pos == end) {
