@@ -2,7 +2,7 @@
  *
  * Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2002 Ananova Ltd
- * Copyright 2002,2003,2004,2005,2006,2007,2009 Olly Betts
+ * Copyright 2002,2003,2004,2005,2006,2007,2009,2010 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -387,7 +387,8 @@ FlintTable::block_to_cursor(Cursor_ * C_, int j, uint4 n) const
     // Check if the block is in the built-in cursor (potentially in
     // modified form).
     if (writable && n == C[j].n) {
-	memcpy(p, C[j].p, block_size);
+	if (p != C[j].p)
+	    memcpy(p, C[j].p, block_size);
     } else {
 	read_block(n, p);
     }
@@ -1126,6 +1127,10 @@ FlintTable::add(const string &key, string tag, bool already_compressed)
     }
     if (!replacement) ++item_count;
     Btree_modified = true;
+    if (cursor_created_since_last_modification) {
+	cursor_created_since_last_modification = false;
+	++cursor_version;
+    }
     RETURN(true);
 }
 
@@ -1159,6 +1164,10 @@ FlintTable::del(const string &key)
 
     item_count--;
     Btree_modified = true;
+    if (cursor_created_since_last_modification) {
+	cursor_created_since_last_modification = false;
+	++cursor_version;
+    }
     RETURN(true);
 }
 
@@ -1560,6 +1569,8 @@ FlintTable::FlintTable(const string & path_, bool readonly_,
 	  Btree_modified(false),
 	  full_compaction(false),
 	  writable(!readonly_),
+	  cursor_created_since_last_modification(false),
+	  cursor_version(0),
 	  split_p(0),
 	  compress_strategy(compress_strategy_),
 	  deflate_zstream(NULL),
@@ -1595,9 +1606,9 @@ FlintTable::lazy_alloc_deflate_zstream() const {
 
     deflate_zstream = new z_stream;
 
-    deflate_zstream->zalloc = reinterpret_cast<alloc_func>(0);
-    deflate_zstream->zfree = reinterpret_cast<free_func>(0);
-    deflate_zstream->opaque = voidpf(0);
+    deflate_zstream->zalloc = Z_NULL;
+    deflate_zstream->zfree = Z_NULL;
+    deflate_zstream->opaque = Z_NULL;
 
     // -15 means raw deflate with 32K LZ77 window (largest)
     // memLevel 9 is the highest (8 is default)
@@ -1633,8 +1644,9 @@ FlintTable::lazy_alloc_inflate_zstream() const {
 
     inflate_zstream = new z_stream;
 
-    inflate_zstream->zalloc = reinterpret_cast<alloc_func>(0);
-    inflate_zstream->zfree = reinterpret_cast<free_func>(0);
+    inflate_zstream->zalloc = Z_NULL;
+    inflate_zstream->zfree = Z_NULL;
+    inflate_zstream->opaque = Z_NULL;
 
     inflate_zstream->next_in = Z_NULL;
     inflate_zstream->avail_in = 0;
@@ -1880,7 +1892,7 @@ FlintTable::commit(flint_revision_number_t revision)
 	changed_n = 0;
 	changed_c = DIR_START;
 	seq_count = SEQ_START_POINT;
-    } catch(...) {
+    } catch (...) {
 	FlintTable::close();
 	throw;
     }
