@@ -1,7 +1,7 @@
 /* flint_table.h: Btree implementation
  *
  * Copyright 1999,2000,2001 BrightStation PLC
- * Copyright 2002,2003,2004,2005,2006,2007,2008,2009 Olly Betts
+ * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2010 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -692,6 +692,12 @@ class XAPIAN_VISIBILITY_DEFAULT FlintTable {
 	/// Set to true when the database is opened to write.
 	bool writable;
 
+	/// Flag for tracking when cursors need to rebuild.
+	mutable bool cursor_created_since_last_modification;
+
+	/// Version count for tracking when cursors need to rebuild.
+	unsigned long cursor_version;
+
 	/* B-tree navigation functions */
 	bool prev(Cursor_ *C_, int j) const {
 	    if (sequential) return prev_for_sequential(C_, j);
