@@ -1,7 +1,7 @@
 /* btree_util.h: common macros/functions in the Btree implementation.
  *
  * Copyright 1999,2000,2001 BrightStation PLC
- * Copyright 2002,2004,2007 Olly Betts
+ * Copyright 2002,2004,2007,2008 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -67,7 +67,7 @@ inline int
 GETINT2(const byte *p, int c)
 {
     Assert(c >= 0);
-    Assert(c + 1 < 65536);
+    Assert(c < 65536 - 1);
     return p[c] << 8 | p[c + 1];
 }
 
@@ -75,7 +75,7 @@ inline void
 SETINT2(byte *p, int c, int x)
 {
     Assert(c >= 0);
-    Assert(c + 1 < 65536);
+    Assert(c < 65536 - 1);
     p[c] = x >> 8;
     p[c + 1] = x;
 }
@@ -84,7 +84,7 @@ inline int
 get_int4(const byte *p, int c)
 {
     Assert(c >= 0);
-    Assert(c + 3 < 65536);
+    Assert(c < 65536 - 3);
     return p[c] << 24 | p[c + 1] << 16 | p[c + 2] << 8 | p[c + 3];
 }
 
@@ -92,7 +92,7 @@ inline void
 set_int4(byte *p, int c, int x)
 {
     Assert(c >= 0);
-    Assert(c + 3 < 65536);
+    Assert(c < 65536 - 3);
     p[c] = x >> 24;
     p[c + 1] = x >> 16;
     p[c + 2] = x >> 8;
