@@ -772,8 +772,7 @@ QuartzWritableDatabase::add_document_(Xapian::docid did,
 		    map<docid, pair<char, termcount> > m;
 		    j = mod_plists.insert(make_pair(tname, m)).first;
 		}
-		Assert(j->second.find(did) == j->second.end());
-		j->second.insert(make_pair(did, make_pair('A', wdf)));
+		j->second[did] = make_pair('A', wdf);
 
 		if (term.positionlist_begin() != term.positionlist_end()) {
 		    database_ro.positionlist_table.set_positionlist(
@@ -914,6 +913,7 @@ QuartzWritableDatabase::replace_document(Xapian::docid did,
 	QuartzTermList termlist(ptrtothis,
 				&database_ro.termlist_table,
 				did, get_doccount());
+	Xapian::TermIterator term = document.termlist_begin();
 
 	termlist.next();
 	while (!termlist.at_end()) {
@@ -946,6 +946,11 @@ QuartzWritableDatabase::replace_document(Xapian::docid did,
 		k->second = make_pair('D', 0u);
 	    }
 
+	    term.skip_to(tname);
+	    if (term == document.termlist_end() || *term != tname) {
+		database_ro.positionlist_table.delete_positionlist(did, tname);
+	    }
+
 	    termlist.next();
 	}
 
@@ -970,7 +975,7 @@ QuartzWritableDatabase::replace_document(Xapian::docid did,
 
 	quartz_doclen_t new_doclen = 0;
 	{
-	    Xapian::TermIterator term = document.termlist_begin();
+	    term = document.termlist_begin();
 	    Xapian::TermIterator term_end = document.termlist_end();
 	    for ( ; term != term_end; ++term) {
 		// Calculate the new document length
