@@ -2,7 +2,7 @@
  * or btree.  Also check the structures inside the tables.
  *
  * Copyright 1999,2000,2001 BrightStation PLC
- * Copyright 2002,2003,2004,2005,2006,2007 Olly Betts
+ * Copyright 2002,2003,2004,2005,2006,2007,2010 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -478,7 +478,9 @@ check_table(string filename, int opts)
 		    if (did >= doclens.size()) {
 			cout << "document id " << did << " is larger than any in the termlist table!" << endl;
 		    } else if (doclens[did] != doclen) {
-			cout << "doclen " << doclen << " doesn't match " << doclens[did] << " in the termlist table" << endl;
+			cout << "document id " << did << ": length " << doclen
+			     << " doesn't match " << doclens[did]
+			     << " in the termlist table" << endl;
 			++errors;
 		    }
 		}
