@@ -1,7 +1,7 @@
 /* rset.h
  *
  * Copyright 1999,2000,2001 BrightStation PLC
- * Copyright 2003,2005,2006 Olly Betts
+ * Copyright 2003,2005,2006,2009 Olly Betts
  * Copyright 2007 Lemur Consulting Ltd
  *
  * This program is free software; you can redistribute it and/or
@@ -66,7 +66,7 @@ class RSetI {
 	 * 
 	 *  @param tname The term for which the reltermfreq is desired.
 	 */
-	void will_want_reltermfreq(string tname);
+	void will_want_reltermfreq(const string & tname);
 
 	/** Calculate the statistics, and add them to a Stats object.
 	 * 
@@ -101,7 +101,7 @@ RSetI::RSetI(const Xapian::Database::Internal *dbroot_, const Xapian::RSet & rse
 }
 
 inline void
-RSetI::will_want_reltermfreq(string tname)
+RSetI::will_want_reltermfreq(const string & tname)
 {
     reltermfreqs[tname] = 0;
 }
