@@ -2,7 +2,7 @@
  *
  * Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2002 Ananova Ltd
- * Copyright 2002,2003,2004,2006,2007,2008 Olly Betts
+ * Copyright 2002,2003,2004,2006,2007,2008,2010 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,6 +31,8 @@
 #include "gnu_getopt.h"
 
 #include <string.h>
+#include <stdlib.h>
+#include "safeerrno.h"
 
 using namespace Xapian;
 using namespace std;
@@ -47,6 +49,7 @@ static bool showdocdata = false;
 static void show_usage() {
     cout << "Usage: "PROG_NAME" [OPTIONS] DATABASE...\n\n"
 "Options:\n"
+"  -a                    show all terms in the database\n"
 "  -r <recno>            for term list(s)\n"
 "  -t <term>             for posting list(s)\n"
 "  -t <term> -r <recno>  for position list(s)\n"
@@ -56,7 +59,8 @@ static void show_usage() {
 "  -V<valueno>           output value valueno for each document in the database\n"
 "  -d                    output document data for each document referred to\n"
 "  -v                    extra info (wdf and len for postlist;\n"
-"                        wdf and termfreq for termlist; number of terms for db)\n"
+"                        wdf and termfreq for termlist; number of terms for db;\n"
+"                        termfreq when showing all terms)\n"
 "      --help            display this help and exit\n"
 "      --version         output version information and exit" << endl;
 }
@@ -67,6 +71,8 @@ show_db_stats(Database &db)
     // Display a few database stats.
     cout << "number of documents = " << db.get_doccount() << endl;
     cout << "average document length = " << db.get_avlength() << endl;
+    cout << "highest document id ever used = " << db.get_lastdocid() << endl;
+
     if (verbose) {
 	// To find the number of terms, we have to count them!
 	// This will take a few seconds or minutes, so only do it if -v
@@ -125,6 +131,32 @@ show_docdata(Database &db,
     }
 }
 
+static void
+show_termlist(const Database &db, Xapian::docid did)
+{
+    TermIterator t, tend;
+    if (did == 0) {
+	t = db.allterms_begin();
+	tend = db.allterms_end();
+	cout << "All terms in database:";
+    } else {
+	t = db.termlist_begin(did);
+	tend = db.termlist_end(did);
+	cout << "Term List for record #" << did << ':';
+    }
+
+    while (t != tend) {
+	cout << separator << *t;
+	if (verbose) {
+	    if (did != 0)
+		cout << ' ' << t.get_wdf();
+	    cout << ' ' << t.get_termfreq();
+	}
+	++t;
+    }
+    cout << endl;
+}
+
 static void
 show_termlists(Database &db,
 	       vector<docid>::const_iterator i,
@@ -132,17 +164,7 @@ show_termlists(Database &db,
 {
     // Display termlists
     while (i != end) {
-	TermIterator t = db.termlist_begin(*i);
-	TermIterator tend = db.termlist_end(*i);
-	cout << "Term List for record #" << *i << ':';
-	while (t != tend) {
-	    cout << separator << *t;
-	    if (verbose) {
-		cout << ' ' << t.get_wdf() << ' ' << t.get_termfreq();
-	    }
-	    ++t;
-	}
-	cout << endl;
+	show_termlist(db, *i);
 	++i;
     }
 }
@@ -164,6 +186,7 @@ main(int argc, char **argv)
 	}
     }
 
+    bool all_terms = false;
     vector<docid> recnos;
     vector<string> terms;
     vector<string> dbs;
@@ -172,11 +195,27 @@ main(int argc, char **argv)
     bool valno_set = false;
 
     int c;
-    while ((c = gnu_getopt(argc, argv, "r:t:s:1vkV::d")) != -1) {
+    while ((c = gnu_getopt(argc, argv, "ar:t:s:1vkV::d")) != -1) {
 	switch (c) {
-	    case 'r':
-		recnos.push_back(atoi(optarg));
+	    case 'a':
+		all_terms = true;
 		break;
+	    case 'r': {
+		char * end;
+		errno = 0;
+		unsigned long n = strtoul(optarg, &end, 10);
+		if (optarg == end || *end) {
+		    cout << "Non-numeric document id: " << optarg << endl;
+		    exit(1);
+		}
+		Xapian::docid did(n);
+		if (errno == ERANGE || n == 0 || did != n) {
+		    cout << "Document id out of range: " << optarg << endl;
+		    exit(1);
+		}
+		recnos.push_back(did);
+		break;
+	    }
 	    case 't':
 		terms.push_back(optarg);
 		break;
@@ -189,7 +228,18 @@ main(int argc, char **argv)
 	    case 'V': case 'k': /* -k for backward compatibility */
 		showvalues = true;
 		if (optarg) {
-		    valno = atoi(optarg);
+		    char * end;
+		    errno = 0;
+		    unsigned long n = strtoul(optarg, &end, 10);
+		    if (optarg == end || *end) {
+			cout << "Non-numeric value slot: " << optarg << endl;
+			exit(1);
+		    }
+		    valno = Xapian::valueno(n);
+		    if (errno == ERANGE || valno != n) {
+			cout << "Value slot out of range: " << optarg << endl;
+			exit(1);
+		    }
 		    valno_set = true;
 		}
 		break;
@@ -229,11 +279,15 @@ main(int argc, char **argv)
     }
 
     try {
-	if (terms.empty() && recnos.empty() && !valno_set) {
+	if (!all_terms && terms.empty() && recnos.empty() && !valno_set) {
 	    show_db_stats(db);
 	    return 0;
 	}
 
+	if (all_terms) {
+	    show_termlist(db, 0);
+	}
+
 	if (!recnos.empty()) {
 	    if (showvalues) {
 		show_values(db, recnos.begin(), recnos.end());
