@@ -115,7 +115,7 @@ main(int argc, char **argv)
 	    }
 	}
 
-	if (!have_database || argc - optind != 1) {
+	if (argc - optind != 1) {
 	    show_usage();
 	    exit(1);
 	}
@@ -130,6 +130,11 @@ main(int argc, char **argv)
 	Xapian::Query query = parser.parse_query(argv[optind]);
 	cout << "Query: " << query.get_description() << endl;
 
+	if (!have_database) {
+	    cout << "No database specified so not running the query." << endl;
+	    exit(0);
+	}
+
 	Xapian::Enquire enquire(db);
 	enquire.set_query(query);
 
