@@ -1,7 +1,7 @@
 /** \file  queryparser.h
  *  \brief parsing a user query string to build a Xapian::Query object
  */
-/* Copyright (C) 2005,2006,2007,2008,2009 Olly Betts
+/* Copyright (C) 2005,2006,2007,2008,2009,2010 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,6 +32,7 @@
 
 namespace Xapian {
 
+class Database;
 class Stem;
 
 /// Base class for stop-word decision functor.
@@ -375,10 +376,20 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
     /// Set the stopper.
     void set_stopper(const Stopper *stop = NULL);
 
-    /** Set the default boolean operator. */
+    /** Set the default operator.
+     *
+     *  This operator is used to combine non-filter query items when no
+     *  explicit operator is used.
+     *
+     *  The most useful values for this are OP_OR (the default) and OP_AND.
+     *  OP_NEAR and OP_PHRASE can also be useful.
+     *
+     *  So for example, 'weather forecast' is parsed as if it were 'weather OR
+     *  forecast' by default.
+     */
     void set_default_op(Query::op default_op);
 
-    /** Get the default boolean operator. */
+    /** Get the current default operator. */
     Query::op get_default_op() const;
 
     /// Specify the database being searched.
@@ -392,6 +403,20 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
      *		multiple values with bitwise-or (|) (default FLAG_DEFAULT).
      *	@param default_prefix  The default term prefix to use (default none).
      *		For example, you can pass "A" when parsing an "Author" field.
+     *
+     *  @exception If the query string can't be parsed, then
+     *		   Xapian::QueryParserError is thrown.  You can get an English
+     *		   error message to report to the user by catching it and
+     *		   calling get_msg() on the caught exception.  The current
+     *		   possible values (in case you want to translate them) are:
+     *
+     *			* Unknown range operation
+     *			* parse error
+     *			* Syntax: <expression> AND <expression>
+     *			* Syntax: <expression> AND NOT <expression>
+     *			* Syntax: <expression> NOT <expression>
+     *			* Syntax: <expression> OR <expression>
+     *			* Syntax: <expression> XOR <expression>
      */
     Query parse_query(const std::string &query_string,
 		      unsigned flags = FLAG_PHRASE|FLAG_BOOLEAN|FLAG_LOVEHATE,
