@@ -29,7 +29,6 @@
 namespace Xapian { class Weight; }
 
 #include <map>
-#include <vector>
 
 class Stats;
 
@@ -62,8 +61,8 @@ class LocalSubMatch : public SubMatch {
     /// Weight object (used as a factory by calling create on it).
     const Xapian::Weight * wt_factory;
 
-    /// The termfreqs and weights of terms used in orig_query.
-    std::map<string, Xapian::MSet::Internal::TermFreqAndWeight> term_info;
+    /// The termfreqs and weights of terms used in orig_query, or NULL.
+    std::map<string, Xapian::MSet::Internal::TermFreqAndWeight> * term_info;
 
   public:
     /// Constructor.
