@@ -2,7 +2,7 @@
  *
  * Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2001,2002 Ananova Ltd
- * Copyright 2002,2003,2004,2005,2006,2007,2008 Olly Betts
+ * Copyright 2002,2003,2004,2005,2006,2007,2008,2010 Olly Betts
  * Copyright 2003 Orange PCS Ltd
  * Copyright 2003 Sam Liddicott
  * Copyright 2007,2008 Lemur Consulting Ltd
@@ -299,7 +299,7 @@ MultiMatch::get_mset(Xapian::doccount first, Xapian::doccount maxitems,
 {
     DEBUGCALL(MATCH, void, "MultiMatch::get_mset", first << ", " << maxitems
 	      << ", " << check_at_least << ", ...");
-    if (check_at_least < maxitems) check_at_least = maxitems;
+    AssertRel(check_at_least,>=,maxitems);
 
     if (!query) {
 	mset = Xapian::MSet(); // FIXME: mset.get_firstitem() will return 0 not first
@@ -913,7 +913,7 @@ new_greatest_weight:
 	Assert(percent_cutoff || docs_matched == items.size());
 	matches_lower_bound = matches_upper_bound = matches_estimated
 	    = items.size();
-    } else if (docs_matched < check_at_least) {
+    } else if (collapse_key == Xapian::BAD_VALUENO && docs_matched < check_at_least) {
 	// We have seen fewer matches than we checked for, so we must have seen
 	// all the matches.
 	DEBUGLINE(MATCH, "Setting bounds equal");
