@@ -23,7 +23,7 @@
 #include <config.h>
 
 #include "orpostlist.h"
-#include "andpostlist.h"
+#include "multiandpostlist.h"
 #include "andmaybepostlist.h"
 #include "omassert.h"
 #include "omdebug.h"
@@ -38,6 +38,7 @@ OrPostList::OrPostList(PostList *left_,
 	  lhead(0), rhead(0), lmax(0), rmax(0), minmax(0), dbsize(dbsize_)
 {
     DEBUGCALL(MATCH, void, "OrPostList", left_ << ", " << right_ << ", " << matcher_ << ", " << dbsize_);
+    AssertRel(left_->get_termfreq_est(),>=,right_->get_termfreq_est());
 }
 
 PostList *
@@ -50,7 +51,7 @@ OrPostList::next(Xapian::weight w_min)
 	if (w_min > lmax) {
 	    if (w_min > rmax) {
 		DEBUGLINE(MATCH, "OR -> AND");
-		ret = new AndPostList(l, r, matcher, dbsize, true);
+		ret = new MultiAndPostList(l, r, lmax, rmax, matcher, dbsize);
 		skip_to_handling_prune(ret, std::max(lhead, rhead) + 1, w_min,
 				       matcher);
 	    } else {
@@ -111,7 +112,7 @@ OrPostList::skip_to(Xapian::docid did, Xapian::weight w_min)
 	if (w_min > lmax) {
 	    if (w_min > rmax) {
 		DEBUGLINE(MATCH, "OR -> AND (in skip_to)");
-		ret = new AndPostList(l, r, matcher, dbsize, true);
+		ret = new MultiAndPostList(l, r, lmax, rmax, matcher, dbsize);
 		did = std::max(did, std::max(lhead, rhead));
 	    } else {
 		DEBUGLINE(MATCH, "OR -> AND MAYBE (in skip_to) (1)");
