@@ -564,12 +564,19 @@ QueryParser::Internal::parse_term(Utf8Iterator &it, const Utf8Iterator &end,
     return term;
 }
 
+class ParserHandler {
+    yyParser * parser;
+
+  public:
+    explicit ParserHandler(yyParser * parser_) : parser(parser_) { }
+    operator yyParser*() { return parser; }
+    ~ParserHandler() { ParseFree(parser); }
+};
+
 Query
 QueryParser::Internal::parse_query(const string &qs, unsigned flags,
 				   const string &default_prefix)
 {
-    yyParser * pParser = ParseAlloc();
-
     // Set value_ranges if we may have to handle value ranges in the query.
     bool value_ranges;
     value_ranges = !valrangeprocs.empty() && (qs.find("..") != string::npos);
@@ -601,6 +608,8 @@ QueryParser::Internal::parse_query(const string &qs, unsigned flags,
 	prefix_stack.push_back(default_prefixinfo);
     }
 
+    ParserHandler pParser(ParseAlloc());
+
     unsigned newprev = ' ';
 main_lex_loop:
     enum {
@@ -1085,7 +1094,6 @@ done:
 	    Parse(pParser, QUOTE, NULL, &state);
 	Parse(pParser, 0, NULL, &state);
     }
-    ParseFree(pParser);
 
     errmsg = state.error;
     return state.query;
@@ -1368,7 +1376,7 @@ class TermList {
 	delete B;\
     } while (0)
 
-#line 1373 "queryparser/queryparser_internal.cc"
+#line 1381 "queryparser/queryparser_internal.cc"
 /* Next is all token values, in a form suitable for use by makeheaders.
 ** This section will be null unless lemon is run with the -m switch.
 */
@@ -1802,9 +1810,9 @@ static void yy_destructor(YYCODETYPE yymajor, YYMINORTYPE *yypminor){
     case 20:
     case 21:
     case 22:
-#line 1368 "queryparser/queryparser.lemony"
+#line 1376 "queryparser/queryparser.lemony"
 {delete (yypminor->yy0);}
-#line 1809 "queryparser/queryparser_internal.cc"
+#line 1817 "queryparser/queryparser_internal.cc"
       break;
     case 25:
     case 26:
@@ -1812,28 +1820,28 @@ static void yy_destructor(YYCODETYPE yymajor, YYMINORTYPE *yypminor){
     case 29:
     case 31:
     case 32:
-#line 1439 "queryparser/queryparser.lemony"
+#line 1447 "queryparser/queryparser.lemony"
 {delete (yypminor->yy73);}
-#line 1819 "queryparser/queryparser_internal.cc"
+#line 1827 "queryparser/queryparser_internal.cc"
       break;
     case 28:
     case 30:
-#line 1535 "queryparser/queryparser.lemony"
+#line 1543 "queryparser/queryparser.lemony"
 {delete (yypminor->yy12);}
-#line 1825 "queryparser/queryparser_internal.cc"
+#line 1833 "queryparser/queryparser_internal.cc"
       break;
     case 33:
     case 34:
     case 36:
     case 37:
-#line 1736 "queryparser/queryparser.lemony"
+#line 1744 "queryparser/queryparser.lemony"
 {(yypminor->yy27)->destroy();}
-#line 1833 "queryparser/queryparser_internal.cc"
+#line 1841 "queryparser/queryparser_internal.cc"
       break;
     case 35:
-#line 1770 "queryparser/queryparser.lemony"
+#line 1778 "queryparser/queryparser.lemony"
 {(yypminor->yy76)->destroy();}
-#line 1838 "queryparser/queryparser_internal.cc"
+#line 1846 "queryparser/queryparser_internal.cc"
       break;
     default:  break;   /* If no destructor action specified: do nothing */
   }
@@ -2066,7 +2074,7 @@ static void yy_reduce(
   **     break;
   */
       case 0:
-#line 1421 "queryparser/queryparser.lemony"
+#line 1429 "queryparser/queryparser.lemony"
 {
     // Save the parsed query in the State structure so we can return it.
     if (yymsp[0].minor.yy73) {
@@ -2076,30 +2084,30 @@ static void yy_reduce(
 	state->query = Query();
     }
 }
-#line 2081 "queryparser/queryparser_internal.cc"
+#line 2089 "queryparser/queryparser_internal.cc"
         break;
       case 1:
-#line 1431 "queryparser/queryparser.lemony"
+#line 1439 "queryparser/queryparser.lemony"
 {
     // Handle a query string with no terms in.
     state->query = Query();
 }
-#line 2089 "queryparser/queryparser_internal.cc"
+#line 2097 "queryparser/queryparser_internal.cc"
         break;
       case 2:
       case 9:
-#line 1442 "queryparser/queryparser.lemony"
+#line 1450 "queryparser/queryparser.lemony"
 { yygotominor.yy73 = yymsp[0].minor.yy73; }
-#line 2095 "queryparser/queryparser_internal.cc"
+#line 2103 "queryparser/queryparser_internal.cc"
         break;
       case 3:
-#line 1445 "queryparser/queryparser.lemony"
+#line 1453 "queryparser/queryparser.lemony"
 { BOOL_OP_TO_QUERY(yygotominor.yy73, yymsp[-2].minor.yy73, Query::OP_AND, yymsp[0].minor.yy73, "AND");   yy_destructor(4,&yymsp[-1].minor);
 }
-#line 2101 "queryparser/queryparser_internal.cc"
+#line 2109 "queryparser/queryparser_internal.cc"
         break;
       case 4:
-#line 1447 "queryparser/queryparser.lemony"
+#line 1455 "queryparser/queryparser.lemony"
 {
     // 'NOT foo' -> '<alldocuments> NOT foo'
     if (!yymsp[-2].minor.yy73 && (state->flags & QueryParser::FLAG_PURE_NOT)) {
@@ -2108,46 +2116,46 @@ static void yy_reduce(
     BOOL_OP_TO_QUERY(yygotominor.yy73, yymsp[-2].minor.yy73, Query::OP_AND_NOT, yymsp[0].minor.yy73, "NOT");
   yy_destructor(5,&yymsp[-1].minor);
 }
-#line 2113 "queryparser/queryparser_internal.cc"
+#line 2121 "queryparser/queryparser_internal.cc"
         break;
       case 5:
-#line 1456 "queryparser/queryparser.lemony"
+#line 1464 "queryparser/queryparser.lemony"
 { BOOL_OP_TO_QUERY(yygotominor.yy73, yymsp[-3].minor.yy73, Query::OP_AND_NOT, yymsp[0].minor.yy73, "AND NOT");   yy_destructor(4,&yymsp[-2].minor);
   yy_destructor(5,&yymsp[-1].minor);
 }
-#line 2120 "queryparser/queryparser_internal.cc"
+#line 2128 "queryparser/queryparser_internal.cc"
         break;
       case 6:
-#line 1459 "queryparser/queryparser.lemony"
+#line 1467 "queryparser/queryparser.lemony"
 { BOOL_OP_TO_QUERY(yygotominor.yy73, yymsp[-3].minor.yy73, Query::OP_AND_NOT, yymsp[0].minor.yy73, "AND");   yy_destructor(4,&yymsp[-2].minor);
   yy_destructor(10,&yymsp[-1].minor);
 }
-#line 2127 "queryparser/queryparser_internal.cc"
+#line 2135 "queryparser/queryparser_internal.cc"
         break;
       case 7:
-#line 1462 "queryparser/queryparser.lemony"
+#line 1470 "queryparser/queryparser.lemony"
 { BOOL_OP_TO_QUERY(yygotominor.yy73, yymsp[-2].minor.yy73, Query::OP_OR, yymsp[0].minor.yy73, "OR");   yy_destructor(2,&yymsp[-1].minor);
 }
-#line 2133 "queryparser/queryparser_internal.cc"
+#line 2141 "queryparser/queryparser_internal.cc"
         break;
       case 8:
-#line 1465 "queryparser/queryparser.lemony"
+#line 1473 "queryparser/queryparser.lemony"
 { BOOL_OP_TO_QUERY(yygotominor.yy73, yymsp[-2].minor.yy73, Query::OP_XOR, yymsp[0].minor.yy73, "XOR");   yy_destructor(3,&yymsp[-1].minor);
 }
-#line 2139 "queryparser/queryparser_internal.cc"
+#line 2147 "queryparser/queryparser_internal.cc"
         break;
       case 10:
-#line 1474 "queryparser/queryparser.lemony"
+#line 1482 "queryparser/queryparser.lemony"
 {
     // Set the argument to NULL, which enables the bool_arg-using rules in
     // expr above to report uses of AND, OR, etc which don't have two
     // arguments.
     yygotominor.yy73 = NULL;
 }
-#line 2149 "queryparser/queryparser_internal.cc"
+#line 2157 "queryparser/queryparser_internal.cc"
         break;
       case 11:
-#line 1486 "queryparser/queryparser.lemony"
+#line 1494 "queryparser/queryparser.lemony"
 {
     yygotominor.yy73 = yymsp[0].minor.yy12->query;
     yymsp[0].minor.yy12->query = NULL;
@@ -2186,19 +2194,19 @@ static void yy_reduce(
     // FIXME what if yygotominor.yy73 && yygotominor.yy73->empty() (all terms are stopwords)?
     delete yymsp[0].minor.yy12;
 }
-#line 2191 "queryparser/queryparser_internal.cc"
+#line 2199 "queryparser/queryparser_internal.cc"
         break;
       case 12:
       case 30:
       case 32:
-#line 1525 "queryparser/queryparser.lemony"
+#line 1533 "queryparser/queryparser.lemony"
 {
     yygotominor.yy73 = yymsp[0].minor.yy73;
 }
-#line 2200 "queryparser/queryparser_internal.cc"
+#line 2208 "queryparser/queryparser_internal.cc"
         break;
       case 13:
-#line 1537 "queryparser/queryparser.lemony"
+#line 1545 "queryparser/queryparser.lemony"
 {
     Query range;
     Xapian::valueno valno = state->value_range(range, yymsp[-1].minor.yy0, yymsp[0].minor.yy0);
@@ -2209,10 +2217,10 @@ static void yy_reduce(
     yygotominor.yy12 = new ProbQuery;
     yygotominor.yy12->filter[filter_group_id(valno)] = range;
 }
-#line 2214 "queryparser/queryparser_internal.cc"
+#line 2222 "queryparser/queryparser_internal.cc"
         break;
       case 14:
-#line 1548 "queryparser/queryparser.lemony"
+#line 1556 "queryparser/queryparser.lemony"
 {
     Query range;
     Xapian::valueno valno = state->value_range(range, yymsp[-1].minor.yy0, yymsp[0].minor.yy0);
@@ -2224,28 +2232,28 @@ static void yy_reduce(
     Query & q = yygotominor.yy12->filter[filter_group_id(valno)];
     q = Query(Query::OP_OR, q, range);
 }
-#line 2229 "queryparser/queryparser_internal.cc"
+#line 2237 "queryparser/queryparser_internal.cc"
         break;
       case 15:
-#line 1560 "queryparser/queryparser.lemony"
+#line 1568 "queryparser/queryparser.lemony"
 {
     yygotominor.yy12 = new ProbQuery;
     yygotominor.yy12->query = yymsp[-1].minor.yy73;
     if (yymsp[0].minor.yy73) add_to_query(yygotominor.yy12->query, state->default_op(), yymsp[0].minor.yy73);
 }
-#line 2238 "queryparser/queryparser_internal.cc"
+#line 2246 "queryparser/queryparser_internal.cc"
         break;
       case 16:
-#line 1566 "queryparser/queryparser.lemony"
+#line 1574 "queryparser/queryparser.lemony"
 {
     yygotominor.yy12 = yymsp[-1].minor.yy12;
     // If yymsp[0].minor.yy73 is a stopword, there's nothing to do here.
     if (yymsp[0].minor.yy73) add_to_query(yygotominor.yy12->query, state->default_op(), yymsp[0].minor.yy73);
 }
-#line 2247 "queryparser/queryparser_internal.cc"
+#line 2255 "queryparser/queryparser_internal.cc"
         break;
       case 17:
-#line 1572 "queryparser/queryparser.lemony"
+#line 1580 "queryparser/queryparser.lemony"
 {
     yygotominor.yy12 = new ProbQuery;
     if (state->default_op() == Query::OP_AND) {
@@ -2255,10 +2263,10 @@ static void yy_reduce(
     }
   yy_destructor(8,&yymsp[-1].minor);
 }
-#line 2260 "queryparser/queryparser_internal.cc"
+#line 2268 "queryparser/queryparser_internal.cc"
         break;
       case 18:
-#line 1581 "queryparser/queryparser.lemony"
+#line 1589 "queryparser/queryparser.lemony"
 {
     yygotominor.yy12 = yymsp[-2].minor.yy12;
     if (state->default_op() == Query::OP_AND) {
@@ -2271,57 +2279,57 @@ static void yy_reduce(
     }
   yy_destructor(8,&yymsp[-1].minor);
 }
-#line 2276 "queryparser/queryparser_internal.cc"
+#line 2284 "queryparser/queryparser_internal.cc"
         break;
       case 19:
-#line 1593 "queryparser/queryparser.lemony"
+#line 1601 "queryparser/queryparser.lemony"
 {
     yygotominor.yy12 = new ProbQuery;
     yygotominor.yy12->hate = yymsp[0].minor.yy73;
   yy_destructor(9,&yymsp[-1].minor);
 }
-#line 2285 "queryparser/queryparser_internal.cc"
+#line 2293 "queryparser/queryparser_internal.cc"
         break;
       case 20:
-#line 1598 "queryparser/queryparser.lemony"
+#line 1606 "queryparser/queryparser.lemony"
 {
     yygotominor.yy12 = yymsp[-2].minor.yy12;
     add_to_query(yygotominor.yy12->hate, Query::OP_OR, yymsp[0].minor.yy73);
   yy_destructor(9,&yymsp[-1].minor);
 }
-#line 2294 "queryparser/queryparser_internal.cc"
+#line 2302 "queryparser/queryparser_internal.cc"
         break;
       case 21:
-#line 1603 "queryparser/queryparser.lemony"
+#line 1611 "queryparser/queryparser.lemony"
 {
     yygotominor.yy12 = new ProbQuery;
     yygotominor.yy12->hate = new Query(yymsp[0].minor.yy0->get_query());
     delete yymsp[0].minor.yy0;
   yy_destructor(9,&yymsp[-1].minor);
 }
-#line 2304 "queryparser/queryparser_internal.cc"
+#line 2312 "queryparser/queryparser_internal.cc"
         break;
       case 22:
-#line 1609 "queryparser/queryparser.lemony"
+#line 1617 "queryparser/queryparser.lemony"
 {
     yygotominor.yy12 = yymsp[-2].minor.yy12;
     add_to_query(yygotominor.yy12->hate, Query::OP_OR, yymsp[0].minor.yy0->get_query());
     delete yymsp[0].minor.yy0;
   yy_destructor(9,&yymsp[-1].minor);
 }
-#line 2314 "queryparser/queryparser_internal.cc"
+#line 2322 "queryparser/queryparser_internal.cc"
         break;
       case 23:
-#line 1615 "queryparser/queryparser.lemony"
+#line 1623 "queryparser/queryparser.lemony"
 {
     yygotominor.yy12 = new ProbQuery;
     yygotominor.yy12->filter[yymsp[0].minor.yy0->get_filter_group_id()] = yymsp[0].minor.yy0->get_query();
     delete yymsp[0].minor.yy0;
 }
-#line 2323 "queryparser/queryparser_internal.cc"
+#line 2331 "queryparser/queryparser_internal.cc"
         break;
       case 24:
-#line 1621 "queryparser/queryparser.lemony"
+#line 1629 "queryparser/queryparser.lemony"
 {
     yygotominor.yy12 = yymsp[-1].minor.yy12;
     // We OR filters with the same prefix...
@@ -2329,10 +2337,10 @@ static void yy_reduce(
     q = Query(Query::OP_OR, q, yymsp[0].minor.yy0->get_query());
     delete yymsp[0].minor.yy0;
 }
-#line 2334 "queryparser/queryparser_internal.cc"
+#line 2342 "queryparser/queryparser_internal.cc"
         break;
       case 25:
-#line 1629 "queryparser/queryparser.lemony"
+#line 1637 "queryparser/queryparser.lemony"
 {
     // LOVE BOOLEAN_FILTER(yymsp[0].minor.yy0) is just the same as BOOLEAN_FILTER
     yygotominor.yy12 = new ProbQuery;
@@ -2340,10 +2348,10 @@ static void yy_reduce(
     delete yymsp[0].minor.yy0;
   yy_destructor(8,&yymsp[-1].minor);
 }
-#line 2345 "queryparser/queryparser_internal.cc"
+#line 2353 "queryparser/queryparser_internal.cc"
         break;
       case 26:
-#line 1636 "queryparser/queryparser.lemony"
+#line 1644 "queryparser/queryparser.lemony"
 {
     // LOVE BOOLEAN_FILTER(yymsp[0].minor.yy0) is just the same as BOOLEAN_FILTER
     yygotominor.yy12 = yymsp[-2].minor.yy12;
@@ -2353,23 +2361,23 @@ static void yy_reduce(
     delete yymsp[0].minor.yy0;
   yy_destructor(8,&yymsp[-1].minor);
 }
-#line 2358 "queryparser/queryparser_internal.cc"
+#line 2366 "queryparser/queryparser_internal.cc"
         break;
       case 27:
-#line 1651 "queryparser/queryparser.lemony"
+#line 1659 "queryparser/queryparser.lemony"
 { yygotominor.yy12 = yymsp[0].minor.yy12; }
-#line 2363 "queryparser/queryparser_internal.cc"
+#line 2371 "queryparser/queryparser_internal.cc"
         break;
       case 28:
-#line 1653 "queryparser/queryparser.lemony"
+#line 1661 "queryparser/queryparser.lemony"
 {
     yygotominor.yy12 = new ProbQuery;
     yygotominor.yy12->query = yymsp[0].minor.yy73;
 }
-#line 2371 "queryparser/queryparser_internal.cc"
+#line 2379 "queryparser/queryparser_internal.cc"
         break;
       case 29:
-#line 1667 "queryparser/queryparser.lemony"
+#line 1675 "queryparser/queryparser.lemony"
 {
     if (state->is_stopword(yymsp[0].minor.yy0)) {
 	yygotominor.yy73 = NULL;
@@ -2379,117 +2387,117 @@ static void yy_reduce(
     }
     delete yymsp[0].minor.yy0;
 }
-#line 2384 "queryparser/queryparser_internal.cc"
+#line 2392 "queryparser/queryparser_internal.cc"
         break;
       case 31:
-#line 1686 "queryparser/queryparser.lemony"
+#line 1694 "queryparser/queryparser.lemony"
 {
     yygotominor.yy73 = new Query(yymsp[0].minor.yy0->get_query_with_auto_synonyms());
     delete yymsp[0].minor.yy0;
 }
-#line 2392 "queryparser/queryparser_internal.cc"
+#line 2400 "queryparser/queryparser_internal.cc"
         break;
       case 33:
-#line 1703 "queryparser/queryparser.lemony"
+#line 1711 "queryparser/queryparser.lemony"
 { yygotominor.yy73 = yymsp[0].minor.yy0->as_wildcarded_query(state); }
-#line 2397 "queryparser/queryparser_internal.cc"
+#line 2405 "queryparser/queryparser_internal.cc"
         break;
       case 34:
-#line 1706 "queryparser/queryparser.lemony"
+#line 1714 "queryparser/queryparser.lemony"
 { yygotominor.yy73 = yymsp[0].minor.yy0->as_partial_query(state); }
-#line 2402 "queryparser/queryparser_internal.cc"
+#line 2410 "queryparser/queryparser_internal.cc"
         break;
       case 35:
-#line 1709 "queryparser/queryparser.lemony"
+#line 1717 "queryparser/queryparser.lemony"
 { yygotominor.yy73 = yymsp[-1].minor.yy27->as_phrase_query();   yy_destructor(20,&yymsp[-2].minor);
   yy_destructor(20,&yymsp[0].minor);
 }
-#line 2409 "queryparser/queryparser_internal.cc"
+#line 2417 "queryparser/queryparser_internal.cc"
         break;
       case 36:
-#line 1712 "queryparser/queryparser.lemony"
+#line 1720 "queryparser/queryparser.lemony"
 { yygotominor.yy73 = yymsp[0].minor.yy27->as_phrase_query(); }
-#line 2414 "queryparser/queryparser_internal.cc"
+#line 2422 "queryparser/queryparser_internal.cc"
         break;
       case 37:
-#line 1714 "queryparser/queryparser.lemony"
+#line 1722 "queryparser/queryparser.lemony"
 {
     yygotominor.yy73 = yymsp[0].minor.yy76->as_group(state);
 }
-#line 2421 "queryparser/queryparser_internal.cc"
+#line 2429 "queryparser/queryparser_internal.cc"
         break;
       case 38:
-#line 1719 "queryparser/queryparser.lemony"
+#line 1727 "queryparser/queryparser.lemony"
 { yygotominor.yy73 = yymsp[0].minor.yy27->as_near_query(); }
-#line 2426 "queryparser/queryparser_internal.cc"
+#line 2434 "queryparser/queryparser_internal.cc"
         break;
       case 39:
-#line 1722 "queryparser/queryparser.lemony"
+#line 1730 "queryparser/queryparser.lemony"
 { yygotominor.yy73 = yymsp[0].minor.yy27->as_adj_query(); }
-#line 2431 "queryparser/queryparser_internal.cc"
+#line 2439 "queryparser/queryparser_internal.cc"
         break;
       case 40:
-#line 1725 "queryparser/queryparser.lemony"
+#line 1733 "queryparser/queryparser.lemony"
 { yygotominor.yy73 = yymsp[-1].minor.yy73;   yy_destructor(21,&yymsp[-2].minor);
   yy_destructor(22,&yymsp[0].minor);
 }
-#line 2438 "queryparser/queryparser_internal.cc"
+#line 2446 "queryparser/queryparser_internal.cc"
         break;
       case 41:
-#line 1727 "queryparser/queryparser.lemony"
+#line 1735 "queryparser/queryparser.lemony"
 {
     yygotominor.yy73 = new Query(yymsp[0].minor.yy0->get_query_with_synonyms());
     delete yymsp[0].minor.yy0;
   yy_destructor(11,&yymsp[-1].minor);
 }
-#line 2447 "queryparser/queryparser_internal.cc"
+#line 2455 "queryparser/queryparser_internal.cc"
         break;
       case 42:
-#line 1738 "queryparser/queryparser.lemony"
+#line 1746 "queryparser/queryparser.lemony"
 {
     yygotominor.yy27 = new TermList;
     yygotominor.yy27->add_positional_term(yymsp[0].minor.yy0);
 }
-#line 2455 "queryparser/queryparser_internal.cc"
+#line 2463 "queryparser/queryparser_internal.cc"
         break;
       case 43:
       case 45:
-#line 1743 "queryparser/queryparser.lemony"
+#line 1751 "queryparser/queryparser.lemony"
 {
     yygotominor.yy27 = yymsp[-1].minor.yy27;
     yygotominor.yy27->add_positional_term(yymsp[0].minor.yy0);
 }
-#line 2464 "queryparser/queryparser_internal.cc"
+#line 2472 "queryparser/queryparser_internal.cc"
         break;
       case 44:
-#line 1755 "queryparser/queryparser.lemony"
+#line 1763 "queryparser/queryparser.lemony"
 {
     yygotominor.yy27 = new TermList;
     yygotominor.yy27->add_positional_term(yymsp[-1].minor.yy0);
     yygotominor.yy27->add_positional_term(yymsp[0].minor.yy0);
 }
-#line 2473 "queryparser/queryparser_internal.cc"
+#line 2481 "queryparser/queryparser_internal.cc"
         break;
       case 46:
-#line 1772 "queryparser/queryparser.lemony"
+#line 1780 "queryparser/queryparser.lemony"
 {
     yygotominor.yy76 = new TermGroup;
     yygotominor.yy76->add_term(yymsp[-1].minor.yy0);
     yygotominor.yy76->add_term(yymsp[0].minor.yy0);
 }
-#line 2482 "queryparser/queryparser_internal.cc"
+#line 2490 "queryparser/queryparser_internal.cc"
         break;
       case 47:
-#line 1778 "queryparser/queryparser.lemony"
+#line 1786 "queryparser/queryparser.lemony"
 {
     yygotominor.yy76 = yymsp[-1].minor.yy76;
     yygotominor.yy76->add_term(yymsp[0].minor.yy0);
 }
-#line 2490 "queryparser/queryparser_internal.cc"
+#line 2498 "queryparser/queryparser_internal.cc"
         break;
       case 48:
       case 50:
-#line 1789 "queryparser/queryparser.lemony"
+#line 1797 "queryparser/queryparser.lemony"
 {
     yygotominor.yy27 = new TermList;
     yygotominor.yy27->add_positional_term(yymsp[-2].minor.yy0);
@@ -2499,11 +2507,11 @@ static void yy_reduce(
 	delete yymsp[-1].minor.yy0;
     }
 }
-#line 2504 "queryparser/queryparser_internal.cc"
+#line 2512 "queryparser/queryparser_internal.cc"
         break;
       case 49:
       case 51:
-#line 1799 "queryparser/queryparser.lemony"
+#line 1807 "queryparser/queryparser.lemony"
 {
     yygotominor.yy27 = yymsp[-2].minor.yy27;
     yygotominor.yy27->add_positional_term(yymsp[0].minor.yy0);
@@ -2512,7 +2520,7 @@ static void yy_reduce(
 	delete yymsp[-1].minor.yy0;
     }
 }
-#line 2517 "queryparser/queryparser_internal.cc"
+#line 2525 "queryparser/queryparser_internal.cc"
         break;
   }
   yygoto = yyRuleInfo[yyruleno].lhs;
@@ -2537,11 +2545,11 @@ static void yy_parse_failed(
   while( !yypParser->yystack.empty() ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will be executed whenever the
   ** parser fails */
-#line 1372 "queryparser/queryparser.lemony"
+#line 1380 "queryparser/queryparser.lemony"
 
     // If we've not already set an error message, set a default one.
     if (!state->error) state->error = "parse error";
-#line 2547 "queryparser/queryparser_internal.cc"
+#line 2555 "queryparser/queryparser_internal.cc"
   ParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
 }
 
