@@ -1,7 +1,7 @@
 /** @file api_backend.cc
  * @brief Backend-related tests.
  */
-/* Copyright (C) 2008,2009 Olly Betts
+/* Copyright (C) 2008,2009,2010 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -261,3 +261,162 @@ DEFINE_TESTCASE(replacedoc8, writable) {
     TEST_EQUAL(p.get_wdf(), 2);
     return true;
 }
+
+/// Test coverage for DatabaseModifiedError.
+DEFINE_TESTCASE(databasemodified1, writable && !inmemory && !remote) {
+    // The inmemory backend doesn't support revisions.
+    //
+    // The remote backend doesn't work as expected here, I think due to
+    // test harness issues.
+    Xapian::WritableDatabase db(get_writable_database());
+    Xapian::Document doc;
+    doc.set_data("cargo");
+    doc.add_term("abc");
+    doc.add_term("def");
+    doc.add_term("ghi");
+    const int N = 500;
+    for (int i = 0; i < N; ++i) {
+	db.add_document(doc);
+    }
+    db.flush();
+
+    Xapian::Database rodb(get_writable_database_as_database());
+    db.add_document(doc);
+    db.flush();
+
+    db.add_document(doc);
+    db.flush();
+
+    db.add_document(doc);
+    try {
+	TEST_EQUAL(*rodb.termlist_begin(N - 1), "abc");
+	return false;
+    } catch (const Xapian::DatabaseModifiedError &) {
+    }
+
+    return true;
+}
+
+/// Regression test for bug#462 fixed in 1.0.19 and 1.1.5.
+DEFINE_TESTCASE(qpmemoryleak1, writable && !inmemory) {
+    // Inmemory never throws DatabaseModifiedError.
+    Xapian::WritableDatabase wdb(get_writable_database());
+    Xapian::Document doc;
+
+    doc.add_term("foo");
+    for (int i = 100; i < 120; ++i) {
+        doc.add_term(om_tostring(i));
+    }
+
+    for (int j = 0; j < 50; ++j) {
+        wdb.add_document(doc);
+    }
+    wdb.flush();
+
+    Xapian::Database database(get_writable_database_as_database());
+    Xapian::QueryParser queryparser;
+    queryparser.set_database(database);
+    TEST_EXCEPTION(Xapian::DatabaseModifiedError,
+	for (int k = 0; k < 3; ++k) {
+	    wdb.add_document(doc);
+	    wdb.flush();
+	    (void)queryparser.parse_query("1", queryparser.FLAG_PARTIAL);
+	}
+    );
+
+    return true;
+}
+
+/// Regression test for ticket#464, fixed in 1.1.6 and 1.0.20.
+DEFINE_TESTCASE(msize1, writable && !inmemory && !remote) {
+    Xapian::WritableDatabase db = get_writable_database();
+    const char * value0 =
+	"ABBCDEFGHIJKLMMNOPQQRSTTUUVVWXYZZaabcdefghhijjkllmnopqrsttuvwxyz";
+    const char * value1 =
+	"EMLEMMMMMMMNMMLMELEDNLEDMLMLDMLMLMLMEDGFHPOPBAHJIQJNGRKCGF";
+    while (*value0) {
+	Xapian::Document doc;
+	doc.add_value(0, string(1, *value0++));
+	if (*value1) {
+	    doc.add_value(1, string(1, *value1++));
+	    doc.add_term("K1");
+	}
+	db.add_document(doc);
+    }
+
+    Xapian::Enquire enq(db);
+    enq.set_sort_by_value(1, false);
+    enq.set_collapse_key(0);
+    enq.set_query(Xapian::Query("K1"));
+
+    Xapian::MSet mset = enq.get_mset(0, 10, 1000);
+    Xapian::doccount lb = mset.get_matches_lower_bound();
+    Xapian::doccount ub = mset.get_matches_upper_bound();
+    Xapian::doccount est = mset.get_matches_estimated();
+    TEST_EQUAL(lb, ub);
+    TEST_EQUAL(lb, est);
+
+    Xapian::MSet mset2 = enq.get_mset(50, 10, 1000);
+    Xapian::doccount lb2 = mset2.get_matches_lower_bound();
+    Xapian::doccount ub2 = mset2.get_matches_upper_bound();
+    Xapian::doccount est2 = mset2.get_matches_estimated();
+    TEST_EQUAL(lb2, ub2);
+    TEST_EQUAL(lb2, est2);
+    TEST_EQUAL(est, est2);
+
+    Xapian::MSet mset3 = enq.get_mset(0, 60);
+    Xapian::doccount lb3 = mset3.get_matches_lower_bound();
+    Xapian::doccount ub3 = mset3.get_matches_upper_bound();
+    Xapian::doccount est3 = mset3.get_matches_estimated();
+    TEST_EQUAL(lb3, ub3);
+    TEST_EQUAL(lb3, est3);
+    TEST_EQUAL(est, est3);
+
+    return true;
+}
+
+/// Regression test for bug related to ticket#464, fixed in 1.1.6 and 1.0.20.
+DEFINE_TESTCASE(msize2, writable && !inmemory && !remote) {
+    Xapian::WritableDatabase db = get_writable_database();
+    const char * value0 = "AAABCDEEFGHIIJJKLLMNNOOPPQQRSTTUVWXYZ";
+    const char * value1 = "MLEMNMLMLMEDEDEMLEMLMLMLPOAHGF";
+    while (*value0) {
+	Xapian::Document doc;
+	doc.add_value(0, string(1, *value0++));
+	if (*value1) {
+	    doc.add_value(1, string(1, *value1++));
+	    doc.add_term("K1");
+	}
+	db.add_document(doc);
+    }
+
+    Xapian::Enquire enq(db);
+    enq.set_sort_by_value(1, false);
+    enq.set_collapse_key(0);
+    enq.set_query(Xapian::Query("K1"));
+
+    Xapian::MSet mset = enq.get_mset(0, 10, 1000);
+    Xapian::doccount lb = mset.get_matches_lower_bound();
+    Xapian::doccount ub = mset.get_matches_upper_bound();
+    Xapian::doccount est = mset.get_matches_estimated();
+    TEST_EQUAL(lb, ub);
+    TEST_EQUAL(lb, est);
+
+    Xapian::MSet mset2 = enq.get_mset(50, 10, 1000);
+    Xapian::doccount lb2 = mset2.get_matches_lower_bound();
+    Xapian::doccount ub2 = mset2.get_matches_upper_bound();
+    Xapian::doccount est2 = mset2.get_matches_estimated();
+    TEST_EQUAL(lb2, ub2);
+    TEST_EQUAL(lb2, est2);
+    TEST_EQUAL(est, est2);
+
+    Xapian::MSet mset3 = enq.get_mset(0, 60);
+    Xapian::doccount lb3 = mset3.get_matches_lower_bound();
+    Xapian::doccount ub3 = mset3.get_matches_upper_bound();
+    Xapian::doccount est3 = mset3.get_matches_estimated();
+    TEST_EQUAL(lb3, ub3);
+    TEST_EQUAL(lb3, est3);
+    TEST_EQUAL(est, est3);
+
+    return true;
+}
