@@ -59,6 +59,14 @@ class BackendManager {
   protected:
     bool create_dir_if_needed(const std::string &dirname);
 
+    /** Virtual method implementing get_database_path().
+     *
+     *  If we just called this get_database_path() then each subclass which
+     *  defined it would also need to un-hide the non-virtual overloaded method
+     *  with "using get_database_path(const std::string&);" or similar.
+     */
+    virtual std::string do_get_database_path(const std::vector<std::string> &files);
+
 #ifdef XAPIAN_HAS_INMEMORY_BACKEND
     /// Get a writable inmemory database instance.
     Xapian::WritableDatabase getwritedb_inmemory(const std::vector<std::string> &dbnames);
@@ -86,6 +94,9 @@ class BackendManager {
     /// Get a writable flint database instance.
     Xapian::WritableDatabase getwritedb_flint(const std::string & name,
 					      const std::vector<std::string> &files);
+
+    /// Get the path of a writable flint database instance.
+    std::string getwritedb_flint_path(const std::string & name);
 #endif
 
 #ifdef XAPIAN_HAS_QUARTZ_BACKEND
@@ -128,9 +139,21 @@ class BackendManager {
     /// Get a database instance of the current type, single file case.
     virtual Xapian::Database get_database(const std::string &dbname);
 
+    /// Get the path of a database instance, if such a thing exists (single file case).
+    std::string get_database_path(const std::string &file);
+
+    /// Get the path of a generated database instance.
+    std::string get_database_path(const std::string &dbname,
+				  void (*gen)(Xapian::WritableDatabase&,
+					      const std::string &),
+				  const std::string &arg);
+
     /// Get a writable database instance.
     virtual Xapian::WritableDatabase get_writable_database(const std::string & name, const std::string & file);
 
+    /// Get the path of a writable database instance, if such a thing exists.
+    virtual std::string get_writable_database_path(const std::string & name);
+
     /// Get a remote database instance with the specified timeout.
     virtual Xapian::Database get_remote_database(const std::vector<std::string> & files, unsigned int timeout);
 
@@ -142,7 +165,7 @@ class BackendManager {
 
     /// Called after each test, to perform any necessary cleanup.
     virtual void clean_up();
- 
+
     /// Get the command line required to run xapian-progsrv.
     static const char * get_xapian_progsrv_command();
 };
